@@ -12,7 +12,7 @@ from jsii.python import classproperty
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
